@@ -1,18 +1,7 @@
 /*
-    Copyright (c) 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "atticaprovider_p.h"
@@ -21,24 +10,25 @@
 #include "question.h"
 #include "tagsfilterchecker.h"
 
+#include <KFormat>
+#include <KLocalizedString>
 #include <QCollator>
 #include <knewstuffcore_debug.h>
-#include <klocalizedstring.h>
 
-#include <attica/providermanager.h>
-#include <attica/provider.h>
-#include <attica/listjob.h>
+#include <attica/accountbalance.h>
+#include <attica/config.h>
 #include <attica/content.h>
 #include <attica/downloaditem.h>
-#include <attica/accountbalance.h>
+#include <attica/listjob.h>
 #include <attica/person.h>
+#include <attica/provider.h>
+#include <attica/providermanager.h>
 
 using namespace Attica;
 
 namespace KNSCore
 {
-
-AtticaProvider::AtticaProvider(const QStringList &categories, const QString& additionalAgentInformation)
+AtticaProvider::AtticaProvider(const QStringList &categories, const QString &additionalAgentInformation)
     : mEntryJob(nullptr)
     , mInitialized(false)
 {
@@ -47,17 +37,17 @@ AtticaProvider::AtticaProvider(const QStringList &categories, const QString& add
         mCategoryMap.insert(category, Attica::Category());
     }
 
-    connect(&m_providerManager, &ProviderManager::providerAdded, this, [=](const Attica::Provider &provider){
+    connect(&m_providerManager, &ProviderManager::providerAdded, this, [=](const Attica::Provider &provider) {
         providerLoaded(provider);
         m_provider.setAdditionalAgentInformation(additionalAgentInformation);
     });
-    connect(&m_providerManager, SIGNAL(authenticationCredentialsMissing(Provider)),
-            SLOT(authenticationCredentialsMissing(Provider)));
+    connect(&m_providerManager, &ProviderManager::authenticationCredentialsMissing, this, &AtticaProvider::onAuthenticationCredentialsMissing);
     connect(this, &Provider::loadComments, this, &AtticaProvider::loadComments);
     connect(this, &Provider::loadPerson, this, &AtticaProvider::loadPerson);
+    connect(this, &Provider::loadBasics, this, &AtticaProvider::loadBasics);
 }
 
-AtticaProvider::AtticaProvider(const Attica::Provider &provider, const QStringList &categories, const QString& additionalAgentInformation)
+AtticaProvider::AtticaProvider(const Attica::Provider &provider, const QStringList &categories, const QString &additionalAgentInformation)
     : mEntryJob(nullptr)
     , mInitialized(false)
 {
@@ -74,10 +64,10 @@ QString AtticaProvider::id() const
     return m_providerId;
 }
 
-void AtticaProvider::authenticationCredentialsMissing(const KNSCore::Provider &)
+void AtticaProvider::onAuthenticationCredentialsMissing(const Attica::Provider &)
 {
     qCDebug(KNEWSTUFFCORE) << "Authentication missing!";
-    // FIXME Show autentication dialog
+    // FIXME Show authentication dialog
 }
 
 bool AtticaProvider::setProviderXML(const QDomElement &xmldata)
@@ -110,6 +100,7 @@ void AtticaProvider::setCachedEntries(const KNSCore::EntryInternal::List &cached
 void AtticaProvider::providerLoaded(const Attica::Provider &provider)
 {
     mName = provider.name();
+    mIcon = provider.icon();
     qCDebug(KNEWSTUFFCORE) << "Added provider: " << provider.name();
 
     m_provider = provider;
@@ -129,14 +120,14 @@ void AtticaProvider::listOfCategoriesLoaded(Attica::BaseJob *listJob)
 
     qCDebug(KNEWSTUFFCORE) << "loading categories: " << mCategoryMap.keys();
 
-    Attica::ListJob<Attica::Category> *job = static_cast<Attica::ListJob<Attica::Category>*>(listJob);
+    auto *job = static_cast<Attica::ListJob<Attica::Category> *>(listJob);
     const Category::List categoryList = job->itemList();
 
     QList<CategoryMetadata> categoryMetadataList;
     for (const Category &category : categoryList) {
         if (mCategoryMap.contains(category.name())) {
             qCDebug(KNEWSTUFFCORE) << "Adding category: " << category.name() << category.displayName();
-            //If there is only the placeholder category, replace it
+            // If there is only the placeholder category, replace it
             if (mCategoryMap.contains(category.name()) && !mCategoryMap.value(category.name()).isValid()) {
                 mCategoryMap.replace(category.name(), category);
             } else {
@@ -150,15 +141,17 @@ void AtticaProvider::listOfCategoriesLoaded(Attica::BaseJob *listJob)
             categoryMetadataList << categoryMetadata;
         }
     }
-    std::sort(categoryMetadataList.begin(), categoryMetadataList.end(), [](const AtticaProvider::CategoryMetadata &i, const AtticaProvider::CategoryMetadata &j) -> bool {
-        const QString a(i.displayName.isEmpty() ? i.name : i.displayName);
-        const QString b(j.displayName.isEmpty() ? j.name : j.displayName);
+    std::sort(categoryMetadataList.begin(),
+              categoryMetadataList.end(),
+              [](const AtticaProvider::CategoryMetadata &i, const AtticaProvider::CategoryMetadata &j) -> bool {
+                  const QString a(i.displayName.isEmpty() ? i.name : i.displayName);
+                  const QString b(j.displayName.isEmpty() ? j.name : j.displayName);
 
-        return (QCollator().compare(a, b) < 0);
-    });
+                  return (QCollator().compare(a, b) < 0);
+              });
 
     bool correct = false;
-    for(auto it = mCategoryMap.cbegin(), itEnd = mCategoryMap.cend(); it!=itEnd; ++it) {
+    for (auto it = mCategoryMap.cbegin(), itEnd = mCategoryMap.cend(); it != itEnd; ++it) {
         if (!it.value().isValid()) {
             qCWarning(KNEWSTUFFCORE) << "Could not find category" << it.key();
         } else {
@@ -168,10 +161,10 @@ void AtticaProvider::listOfCategoriesLoaded(Attica::BaseJob *listJob)
 
     if (correct) {
         mInitialized = true;
-        emit providerInitialized(this);
-        emit categoriesMetadataLoded(categoryMetadataList);
+        Q_EMIT providerInitialized(this);
+        Q_EMIT categoriesMetadataLoded(categoryMetadataList);
     } else {
-        emit signalErrorCode(KNSCore::ConfigFileError, i18n("All categories are missing"), QVariant());
+        Q_EMIT signalErrorCode(KNSCore::ConfigFileError, i18n("All categories are missing"), QVariant());
     }
 }
 
@@ -189,24 +182,24 @@ void AtticaProvider::loadEntries(const KNSCore::Provider::SearchRequest &request
 
     mCurrentRequest = request;
     switch (request.filter) {
-        case None:
-            break;
-        case ExactEntryId: {
-            ItemJob<Content> *job = m_provider.requestContent(request.searchTerm);
-            connect(job, &BaseJob::finished, this, &AtticaProvider::detailsLoaded);
-            job->start();
-            return;
+    case None:
+        break;
+    case ExactEntryId: {
+        ItemJob<Content> *job = m_provider.requestContent(request.searchTerm);
+        connect(job, &BaseJob::finished, this, &AtticaProvider::detailsLoaded);
+        job->start();
+        return;
+    }
+    case Installed:
+        if (request.page == 0) {
+            Q_EMIT loadingFinished(request, installedEntries());
+        } else {
+            Q_EMIT loadingFinished(request, EntryInternal::List());
         }
-        case Installed:
-            if (request.page == 0) {
-                emit loadingFinished(request, installedEntries());
-            } else {
-                emit loadingFinished(request, EntryInternal::List());
-            }
-            return;
-        case Updates:
-            checkForUpdates();
-            return;
+        return;
+    case Updates:
+        checkForUpdates();
+        return;
     }
 
     Attica::Provider::SortMode sorting = atticaSortMode(request.sortMode);
@@ -217,7 +210,7 @@ void AtticaProvider::loadEntries(const KNSCore::Provider::SearchRequest &request
         categoriesToSearch = mCategoryMap.values();
     } else {
         categoriesToSearch.reserve(request.categories.size());
-        for (const QString &categoryName : qAsConst(request.categories)) {
+        for (const QString &categoryName : std::as_const(request.categories)) {
             categoriesToSearch.append(mCategoryMap.values(categoryName));
         }
     }
@@ -231,7 +224,11 @@ void AtticaProvider::loadEntries(const KNSCore::Provider::SearchRequest &request
 
 void AtticaProvider::checkForUpdates()
 {
-    for (const EntryInternal &e : qAsConst(mCachedEntries)) {
+    if (mCachedEntries.isEmpty()) {
+        Q_EMIT loadingFinished(mCurrentRequest, {});
+    }
+
+    for (const EntryInternal &e : std::as_const(mCachedEntries)) {
         ItemJob<Content> *job = m_provider.requestContent(e.uniqueId());
         connect(job, &BaseJob::finished, this, &AtticaProvider::detailsLoaded);
         m_updateJobs.insert(job);
@@ -250,22 +247,22 @@ void AtticaProvider::loadEntryDetails(const KNSCore::EntryInternal &entry)
 void AtticaProvider::detailsLoaded(BaseJob *job)
 {
     if (jobSuccess(job)) {
-        ItemJob<Content> *contentJob = static_cast<ItemJob<Content>*>(job);
+        auto *contentJob = static_cast<ItemJob<Content> *>(job);
         Content content = contentJob->result();
         EntryInternal entry = entryFromAtticaContent(content);
-        emit entryDetailsLoaded(entry);
+        Q_EMIT entryDetailsLoaded(entry);
         qCDebug(KNEWSTUFFCORE) << "check update finished: " << entry.name();
     }
 
     if (m_updateJobs.remove(job) && m_updateJobs.isEmpty()) {
         qCDebug(KNEWSTUFFCORE) << "check update finished.";
         QList<EntryInternal> updatable;
-        for (const EntryInternal &entry : qAsConst(mCachedEntries)) {
+        for (const EntryInternal &entry : std::as_const(mCachedEntries)) {
             if (entry.status() == KNS3::Entry::Updateable) {
                 updatable.append(entry);
             }
         }
-        emit loadingFinished(mCurrentRequest, updatable);
+        Q_EMIT loadingFinished(mCurrentRequest, updatable);
     }
 }
 
@@ -275,22 +272,25 @@ void AtticaProvider::categoryContentsLoaded(BaseJob *job)
         return;
     }
 
-    ListJob<Content> *listJob = static_cast<ListJob<Content>*>(job);
-    Content::List contents = listJob->itemList();
+    auto *listJob = static_cast<ListJob<Content> *>(job);
+    const Content::List contents = listJob->itemList();
 
     EntryInternal::List entries;
     TagsFilterChecker checker(tagFilter());
     TagsFilterChecker downloadschecker(downloadTagFilter());
     for (const Content &content : contents) {
         if (!content.isValid()) {
-            qCDebug(KNEWSTUFFCORE) << "Filtered out an invalid entry. This suggests something is not right on the originating server. Please contact the administrators of" << name() << "and inform them there is an issue with content in the category or categories" << mCurrentRequest.categories;
+            qCDebug(KNEWSTUFFCORE)
+                << "Filtered out an invalid entry. This suggests something is not right on the originating server. Please contact the administrators of"
+                << name() << "and inform them there is an issue with content in the category or categories" << mCurrentRequest.categories;
             continue;
         }
         if (checker.filterAccepts(content.tags())) {
             bool filterAcceptsDownloads = true;
             if (content.downloads() > 0) {
                 filterAcceptsDownloads = false;
-                for (const Attica::DownloadDescription &dli : content.downloadUrlDescriptions()) {
+                const QList<Attica::DownloadDescription> descs = content.downloadUrlDescriptions();
+                for (const Attica::DownloadDescription &dli : descs) {
                     if (downloadschecker.filterAccepts(dli.tags())) {
                         filterAcceptsDownloads = true;
                         break;
@@ -309,21 +309,21 @@ void AtticaProvider::categoryContentsLoaded(BaseJob *job)
     }
 
     qCDebug(KNEWSTUFFCORE) << "loaded: " << mCurrentRequest.hashForRequest() << " count: " << entries.size();
-    emit loadingFinished(mCurrentRequest, entries);
+    Q_EMIT loadingFinished(mCurrentRequest, entries);
     mEntryJob = nullptr;
 }
 
 Attica::Provider::SortMode AtticaProvider::atticaSortMode(const SortMode &sortMode)
 {
-    switch(sortMode) {
-        case Newest:
-            return Attica::Provider::Newest;
-        case Alphabetical:
-            return Attica::Provider::Alphabetical;
-        case Downloads:
-            return Attica::Provider::Downloads;
-        default:
-            return Attica::Provider::Rating;
+    switch (sortMode) {
+    case Newest:
+        return Attica::Provider::Newest;
+    case Alphabetical:
+        return Attica::Provider::Alphabetical;
+    case Downloads:
+        return Attica::Provider::Downloads;
+    default:
+        return Attica::Provider::Rating;
     }
 }
 
@@ -352,13 +352,14 @@ void AtticaProvider::loadPayloadLink(const KNSCore::EntryInternal &entry, int li
 
 void AtticaProvider::loadComments(const EntryInternal &entry, int commentsPerPage, int page)
 {
-    ListJob<Attica::Comment> *job = m_provider.requestComments(Attica::Comment::ContentComment, entry.uniqueId(), QLatin1String("0"), page, commentsPerPage);
+    ListJob<Attica::Comment> *job = m_provider.requestComments(Attica::Comment::ContentComment, entry.uniqueId(), QStringLiteral("0"), page, commentsPerPage);
     connect(job, &BaseJob::finished, this, &AtticaProvider::loadedComments);
     job->start();
 }
 
 /// TODO KF6 QList is discouraged, and we'll probably want to switch this (and the rest of the KNS library) to QVector instead
-QList<std::shared_ptr<KNSCore::Comment>> getCommentsList(const Attica::Comment::List &comments, std::shared_ptr<KNSCore::Comment> parent) {
+QList<std::shared_ptr<KNSCore::Comment>> getCommentsList(const Attica::Comment::List &comments, std::shared_ptr<KNSCore::Comment> parent)
+{
     QList<std::shared_ptr<KNSCore::Comment>> knsComments;
     for (const Attica::Comment &comment : comments) {
         qCDebug(KNEWSTUFFCORE) << "Appending comment with id" << comment.id() << ", which has" << comment.childCount() << "children";
@@ -387,11 +388,11 @@ void AtticaProvider::loadedComments(Attica::BaseJob *baseJob)
         return;
     }
 
-    ListJob<Attica::Comment> *job = static_cast<ListJob<Attica::Comment>*>(baseJob);
+    auto *job = static_cast<ListJob<Attica::Comment> *>(baseJob);
     Attica::Comment::List comments = job->itemList();
 
     QList<std::shared_ptr<KNSCore::Comment>> receivedComments = getCommentsList(comments, nullptr);
-    emit commentsLoaded(receivedComments);
+    Q_EMIT commentsLoaded(receivedComments);
 }
 
 void AtticaProvider::loadPerson(const QString &username)
@@ -410,17 +411,52 @@ void AtticaProvider::loadedPerson(Attica::BaseJob *baseJob)
         return;
     }
 
-    ItemJob<Attica::Person> *job = static_cast<ItemJob<Attica::Person>*>(baseJob);
+    auto *job = static_cast<ItemJob<Attica::Person> *>(baseJob);
     Attica::Person person = job->result();
 
     auto author = std::make_shared<KNSCore::Author>();
-    author->setId(job->property("username").toString()); // This is a touch hack-like, but it ensures we actually have the data in case it is not returned by the server
-    author->setName(QString::fromLatin1("%1 %2").arg(person.firstName()).arg(person.lastName()).trimmed());
+    // This is a touch hack-like, but it ensures we actually have the data in case it is not returned by the server
+    author->setId(job->property("username").toString());
+    author->setName(QStringLiteral("%1 %2").arg(person.firstName(), person.lastName()).trimmed());
     author->setHomepage(person.homepage());
     author->setProfilepage(person.extendedAttribute(QStringLiteral("profilepage")));
     author->setAvatarUrl(person.avatarUrl());
     author->setDescription(person.extendedAttribute(QStringLiteral("description")));
-    emit personLoaded(author);
+    Q_EMIT personLoaded(author);
+}
+
+void AtticaProvider::loadBasics()
+{
+    Attica::ItemJob<Attica::Config> *configJob = m_provider.requestConfig();
+    connect(configJob, &BaseJob::finished, this, &AtticaProvider::loadedConfig);
+    configJob->start();
+}
+
+void AtticaProvider::loadedConfig(Attica::BaseJob *baseJob)
+{
+    if (jobSuccess(baseJob)) {
+        auto *job = static_cast<ItemJob<Attica::Config> *>(baseJob);
+        Attica::Config config = job->result();
+        setVersion(config.version());
+        setSupportsSsl(config.ssl());
+        setContactEmail(config.contact());
+        QString protocol{QStringLiteral("http")};
+        if (config.ssl()) {
+            protocol = QStringLiteral("https");
+        }
+        // There is usually no protocol in the website and host, but in case
+        // there is, trust what's there
+        if (config.website().contains(QLatin1String("://"))) {
+            setWebsite(QUrl(config.website()));
+        } else {
+            setWebsite(QUrl(QLatin1String("%1://%2").arg(protocol).arg(config.website())));
+        }
+        if (config.host().contains(QLatin1String("://"))) {
+            setHost(QUrl(config.host()));
+        } else {
+            setHost(QUrl(QLatin1String("%1://%2").arg(protocol).arg(config.host())));
+        }
+    }
 }
 
 void AtticaProvider::accountBalanceLoaded(Attica::BaseJob *baseJob)
@@ -429,21 +465,22 @@ void AtticaProvider::accountBalanceLoaded(Attica::BaseJob *baseJob)
         return;
     }
 
-    ItemJob<AccountBalance> *job = static_cast<ItemJob<AccountBalance>*>(baseJob);
+    auto *job = static_cast<ItemJob<AccountBalance> *>(baseJob);
     AccountBalance item = job->result();
 
     QPair<EntryInternal, int> pair = mDownloadLinkJobs.take(job);
     EntryInternal entry(pair.first);
     Content content = mCachedContent.value(entry.uniqueId());
     if (content.downloadUrlDescription(pair.second).priceAmount() < item.balance()) {
-        qCDebug(KNEWSTUFFCORE) << "Your balance is greater than the price."
-                   << content.downloadUrlDescription(pair.second).priceAmount() << " balance: " << item.balance();
+        qCDebug(KNEWSTUFFCORE) << "Your balance is greater than the price." << content.downloadUrlDescription(pair.second).priceAmount()
+                               << " balance: " << item.balance();
         Question question;
+        question.setEntry(entry);
         question.setQuestion(i18nc("the price of a download item, parameter 1 is the currency, 2 is the price",
-                "This item costs %1 %2.\nDo you want to buy it?",
-                item.currency(), content.downloadUrlDescription(pair.second).priceAmount()
-            ));
-        if(question.ask() == Question::YesResponse) {
+                                   "This item costs %1 %2.\nDo you want to buy it?",
+                                   item.currency(),
+                                   content.downloadUrlDescription(pair.second).priceAmount()));
+        if (question.ask() == Question::YesResponse) {
             ItemJob<DownloadItem> *job = m_provider.downloadLink(entry.uniqueId(), QString::number(pair.second));
             connect(job, &BaseJob::finished, this, &AtticaProvider::downloadItemLoaded);
             mDownloadLinkJobs[job] = qMakePair(entry, pair.second);
@@ -452,10 +489,11 @@ void AtticaProvider::accountBalanceLoaded(Attica::BaseJob *baseJob)
             return;
         }
     } else {
-        qCDebug(KNEWSTUFFCORE) << "You don't have enough money on your account!"
-               << content.downloadUrlDescription(0).priceAmount() << " balance: " << item.balance();
-        emit signalInformation(i18n("Your account balance is too low:\nYour balance: %1\nPrice: %2",
-                                     item.balance(), content.downloadUrlDescription(0).priceAmount()));
+        qCDebug(KNEWSTUFFCORE) << "You don't have enough money on your account!" << content.downloadUrlDescription(0).priceAmount()
+                               << " balance: " << item.balance();
+        Q_EMIT signalInformation(i18n("Your account balance is too low:\nYour balance: %1\nPrice: %2", //
+                                      item.balance(),
+                                      content.downloadUrlDescription(0).priceAmount()));
     }
 }
 
@@ -465,18 +503,18 @@ void AtticaProvider::downloadItemLoaded(BaseJob *baseJob)
         return;
     }
 
-    ItemJob<DownloadItem> *job = static_cast<ItemJob<DownloadItem>*>(baseJob);
+    auto *job = static_cast<ItemJob<DownloadItem> *>(baseJob);
     DownloadItem item = job->result();
 
     EntryInternal entry = mDownloadLinkJobs.take(job).first;
     entry.setPayload(QString(item.url().toString()));
-    emit payloadLinkLoaded(entry);
+    Q_EMIT payloadLinkLoaded(entry);
 }
 
 EntryInternal::List AtticaProvider::installedEntries() const
 {
     EntryInternal::List entries;
-    for (const EntryInternal &entry : qAsConst(mCachedEntries)) {
+    for (const EntryInternal &entry : std::as_const(mCachedEntries)) {
         if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
             entries.append(entry);
         }
@@ -496,7 +534,7 @@ void AtticaProvider::votingFinished(Attica::BaseJob *job)
     if (!jobSuccess(job)) {
         return;
     }
-    emit signalInformation(i18nc("voting for an item (good/bad)", "Your vote was recorded."));
+    Q_EMIT signalInformation(i18nc("voting for an item (good/bad)", "Your vote was recorded."));
 }
 
 void AtticaProvider::becomeFan(const EntryInternal &entry)
@@ -511,7 +549,7 @@ void AtticaProvider::becomeFanFinished(Attica::BaseJob *job)
     if (!jobSuccess(job)) {
         return;
     }
-    emit signalInformation(i18n("You are now a fan."));
+    Q_EMIT signalInformation(i18n("You are now a fan."));
 }
 
 bool AtticaProvider::jobSuccess(Attica::BaseJob *job) const
@@ -522,15 +560,43 @@ bool AtticaProvider::jobSuccess(Attica::BaseJob *job) const
     qCDebug(KNEWSTUFFCORE) << "job error: " << job->metadata().error() << " status code: " << job->metadata().statusCode() << job->metadata().message();
 
     if (job->metadata().error() == Attica::Metadata::NetworkError) {
-        emit signalErrorCode(KNSCore::NetworkError, i18n("Network error %1: %2", job->metadata().statusCode(), job->metadata().statusString()), job->metadata().statusCode());
+        if (job->metadata().statusCode() == 503) {
+            QDateTime retryAfter;
+            static const QByteArray retryAfterKey{"Retry-After"};
+            for (const QNetworkReply::RawHeaderPair &headerPair : job->metadata().headers()) {
+                if (headerPair.first == retryAfterKey) {
+                    // Retry-After is not a known header, so we need to do a bit of running around to make that work
+                    // Also, the fromHttpDate function is in the private qnetworkrequest header, so we can't use that
+                    // So, simple workaround, just pass it through a dummy request and get a formatted date out (the
+                    // cost is sufficiently low here, given we've just done a bunch of i/o heavy things, so...)
+                    QNetworkRequest dummyRequest;
+                    dummyRequest.setRawHeader(QByteArray{"Last-Modified"}, headerPair.second);
+                    retryAfter = dummyRequest.header(QNetworkRequest::LastModifiedHeader).toDateTime();
+                    break;
+                }
+            }
+            static const KFormat formatter;
+            Q_EMIT signalErrorCode(KNSCore::TryAgainLaterError,
+                                   i18n("The service is currently undergoing maintenance and is expected to be back in %1.",
+                                        formatter.formatSpelloutDuration(retryAfter.toMSecsSinceEpoch() - QDateTime::currentMSecsSinceEpoch())),
+                                   {retryAfter});
+        } else {
+            Q_EMIT signalErrorCode(KNSCore::NetworkError,
+                                   i18n("Network error %1: %2", job->metadata().statusCode(), job->metadata().statusString()),
+                                   job->metadata().statusCode());
+        }
     }
     if (job->metadata().error() == Attica::Metadata::OcsError) {
         if (job->metadata().statusCode() == 200) {
-            emit signalErrorCode(KNSCore::OcsError, i18n("Too many requests to server. Please try again in a few minutes."), job->metadata().statusCode());
+            Q_EMIT signalErrorCode(KNSCore::OcsError, i18n("Too many requests to server. Please try again in a few minutes."), job->metadata().statusCode());
         } else if (job->metadata().statusCode() == 405) {
-            emit signalErrorCode(KNSCore::OcsError, i18n("The Open Collaboration Services instance %1 does not support the attempted function.", name()), job->metadata().statusCode());
+            Q_EMIT signalErrorCode(KNSCore::OcsError,
+                                   i18n("The Open Collaboration Services instance %1 does not support the attempted function.", name()),
+                                   job->metadata().statusCode());
         } else {
-            emit signalErrorCode(KNSCore::OcsError, i18n("Unknown Open Collaboration Service API error. (%1)", job->metadata().statusCode()), job->metadata().statusCode());
+            Q_EMIT signalErrorCode(KNSCore::OcsError,
+                                   i18n("Unknown Open Collaboration Service API error. (%1)", job->metadata().statusCode()),
+                                   job->metadata().statusCode());
         }
     }
     return false;
@@ -551,8 +617,8 @@ EntryInternal AtticaProvider::entryFromAtticaContent(const Attica::Content &cont
     if (index >= 0) {
         EntryInternal &cacheEntry = mCachedEntries[index];
         // check if updateable
-        if (((cacheEntry.status() == KNS3::Entry::Installed) || (cacheEntry.status() == KNS3::Entry::Updateable)) &&
-                ((cacheEntry.version() != entry.version()) || (cacheEntry.releaseDate() != entry.releaseDate()))) {
+        if (((cacheEntry.status() == KNS3::Entry::Installed) || (cacheEntry.status() == KNS3::Entry::Updateable))
+            && ((cacheEntry.version() != entry.version()) || (cacheEntry.releaseDate() != entry.releaseDate()))) {
             cacheEntry.setStatus(KNS3::Entry::Updateable);
             cacheEntry.setUpdateVersion(entry.version());
             cacheEntry.setUpdateReleaseDate(entry.releaseDate());
@@ -614,3 +680,4 @@ EntryInternal AtticaProvider::entryFromAtticaContent(const Attica::Content &cont
 
 } // namespace
 
+#include "moc_atticaprovider_p.cpp"
