@@ -1,28 +1,18 @@
 /*
-    Copyright (c) 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
+
 #ifndef KNEWSTUFF3_ATTICAPROVIDER_P_H
 #define KNEWSTUFF3_ATTICAPROVIDER_P_H
 
-#include <QSet>
 #include <QPointer>
+#include <QSet>
 
-#include <attica/providermanager.h>
-#include <attica/provider.h>
 #include <attica/content.h>
+#include <attica/provider.h>
+#include <attica/providermanager.h>
 
 #include "provider.h"
 
@@ -45,12 +35,12 @@ namespace KNSCore
  *
  * @internal
  */
-class AtticaProvider: public Provider
+class AtticaProvider : public Provider
 {
     Q_OBJECT
 public:
-    explicit AtticaProvider(const QStringList &categories);
-    AtticaProvider(const Attica::Provider &provider, const QStringList &categories);
+    explicit AtticaProvider(const QStringList &categories, const QString &additionalAgentInformation);
+    AtticaProvider(const Attica::Provider &provider, const QStringList &categories, const QString &additionalAgentInformation);
 
     QString id() const override;
 
@@ -75,6 +65,12 @@ public:
      * @see Provider::loadPerson(const QString &username)
      */
     Q_SLOT void loadPerson(const QString &username);
+    /**
+     * The slot which causes the provider's basic information to be fetched.
+     * For the Attica provider, this translates to an OCS Config call
+     * @see Provider::loadBasics()
+     */
+    Q_SLOT void loadBasics();
 
     bool userCanVote() override
     {
@@ -88,18 +84,24 @@ public:
     }
     void becomeFan(const EntryInternal &entry) override;
 
+    Attica::Provider *provider()
+    {
+        return &m_provider;
+    }
+
 private Q_SLOTS:
     void providerLoaded(const Attica::Provider &provider);
     void listOfCategoriesLoaded(Attica::BaseJob *);
     void categoryContentsLoaded(Attica::BaseJob *job);
     void downloadItemLoaded(Attica::BaseJob *job);
     void accountBalanceLoaded(Attica::BaseJob *job);
-    void authenticationCredentialsMissing(const Provider &);
+    void onAuthenticationCredentialsMissing(const Attica::Provider &);
     void votingFinished(Attica::BaseJob *);
     void becomeFanFinished(Attica::BaseJob *job);
     void detailsLoaded(Attica::BaseJob *job);
     void loadedComments(Attica::BaseJob *job);
     void loadedPerson(Attica::BaseJob *job);
+    void loadedConfig(Attica::BaseJob *job);
 
 private:
     void checkForUpdates();
@@ -111,7 +113,7 @@ private:
     EntryInternal entryFromAtticaContent(const Attica::Content &);
 
     // the attica categories we are interested in (e.g. Wallpaper, Application, Vocabulary File...)
-    QHash<QString, Attica::Category> mCategoryMap;
+    QMultiHash<QString, Attica::Category> mCategoryMap;
 
     Attica::ProviderManager m_providerManager;
     Attica::Provider m_provider;
@@ -122,7 +124,7 @@ private:
     // Associate job and entry, this is needed when fetching
     // download links or the account balance in order to continue
     // when the result is there.
-    QHash<Attica::BaseJob *, QPair<EntryInternal, int> > mDownloadLinkJobs;
+    QHash<Attica::BaseJob *, QPair<EntryInternal, int>> mDownloadLinkJobs;
 
     // keep track of the current request
     QPointer<Attica::BaseJob> mEntryJob;
