@@ -7,6 +7,8 @@
 
 #include "button.h"
 
+#if KNEWSTUFF_BUILD_DEPRECATED_SINCE(5, 91)
+
 #include "entry_p.h"
 #include "qtquickdialogwrapper.h"
 #include "ui/widgetquestionlistener.h"
@@ -42,10 +44,7 @@ Button::Button(QWidget *parent)
     init();
 }
 
-Button::~Button()
-{
-    delete d;
-}
+Button::~Button() = default;
 
 void Button::init()
 {
@@ -92,3 +91,7 @@ void Button::showDialog()
 }
 
 }
+
+#include "moc_button.cpp"
+
+#endif
