@@ -24,7 +24,6 @@
 #include <KShell>
 #include <QDesktopServices>
 #include <knewstuffcore_debug.h>
-#include <memory>
 
 #include <QDir>
 #include <QDirIterator>
@@ -1251,3 +1250,5 @@ QVector<Attica::Provider *> Engine::atticaProviders() const
     }
     return ret;
 }
+
+#include "moc_engine.cpp"
