@@ -7,10 +7,9 @@
 
 #include "itemsmodel.h"
 
-#include <knewstuffcore_debug.h>
 #include <KLocalizedString>
+#include <knewstuffcore_debug.h>
 
-#include "entryinternal.h"
 #include "engine.h"
 #include "imageloader_p.h"
 
@@ -19,7 +18,6 @@ namespace KNSCore
 ItemsModel::ItemsModel(Engine *engine, QObject *parent)
     : QAbstractListModel(parent)
     , m_engine(engine)
-    , m_hasPreviewImages(false)
 {
 }
 
@@ -61,7 +59,7 @@ void ItemsModel::addEntry(const EntryInternal &entry)
         if (!m_hasPreviewImages && !preview.isEmpty()) {
             m_hasPreviewImages = true;
             if (rowCount() > 0) {
-                emit dataChanged(index(0, 0), index(rowCount() - 1, 0));
+                Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, 0));
             }
         }
 
@@ -91,7 +89,7 @@ void ItemsModel::slotEntryChanged(const EntryInternal &entry)
 {
     int i = m_entries.indexOf(entry);
     QModelIndex entryIndex = index(i, 0);
-    emit dataChanged(entryIndex, entryIndex);
+    Q_EMIT dataChanged(entryIndex, entryIndex);
 }
 
 void ItemsModel::clearEntries()
@@ -117,3 +115,4 @@ bool ItemsModel::hasPreviewImages() const
 
 } // end KNS namespace
 
+#include "moc_itemsmodel.cpp"
