@@ -12,8 +12,6 @@
 
 #include "knewstuffquick_debug.h"
 
-#include <memory>
-
 namespace KNewStuffQuick
 {
 class CommentsModelPrivate
@@ -136,3 +134,5 @@ bool KNewStuffQuick::CommentsModel::filterAcceptsRow(int sourceRow, const QModel
     }
     return result;
 }
+
+#include "moc_commentsmodel.cpp"
