@@ -18,6 +18,7 @@
 #include "searchpresetmodel.h"
 
 #include "provider.h"
+#include "providersmodel.h"
 #include "question.h"
 
 #include <QQmlEngine>
@@ -73,6 +74,7 @@ void QmlPlugins::registerTypes(const char *uri)
                                                                                                    QQmlEngine::CppOwnership);
                                                                         return KNewStuffQuick::QuickQuestionListener::instance();
                                                                     });
+    qmlRegisterUncreatableType<KNSCore::EntryInternal>(uri, 1, 91, "Entry", QStringLiteral("Entries should only be created by the engine"));
 
     // Version 1.67
     qmlRegisterUncreatableType<KNSCore::EntryWrapper>(
@@ -95,4 +97,9 @@ void QmlPlugins::registerTypes(const char *uri)
         83,
         "SearchPresetModel",
         QStringLiteral("This should only be created by the Engine, and provides the SearchPresets available in that engine"));
+
+    // Version 1.85
+    qmlRegisterType<KNSCore::ProvidersModel>(uri, 1, 85, "ProvidersModel");
 }
+
+#include "moc_qmlplugin.cpp"
