@@ -65,14 +65,36 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
     mIcon = iconurl;
 
     QDomNode n;
+    QLocale::Language systemLanguage = QLocale::system().language();
+    QString firstName;
     for (n = xmldata.firstChild(); !n.isNull(); n = n.nextSibling()) {
         QDomElement e = n.toElement();
         if (e.tagName() == QLatin1String("title")) {
-            // QString lang = e.attribute("lang");
-            mName = e.text().trimmed();
-            qCDebug(KNEWSTUFFCORE) << "add name for provider (" << this << "): " << e.text();
+            const QString lang{e.attribute(QLatin1String("lang"))};
+            bool useThisTitle{false};
+            if (mName.isEmpty() && lang.isEmpty()) {
+                // If we have no title as yet, and we've also got no language defined, this is the default
+                // and name we need to set it, even if we might override it later
+                useThisTitle = true;
+            } else {
+                const QLocale locale(lang);
+                if (systemLanguage == locale.language()) {
+                    useThisTitle = true;
+                }
+            }
+            if (useThisTitle) {
+                mName = e.text().trimmed();
+                qCDebug(KNEWSTUFFCORE) << "add name for provider (" << this << "): " << e.text();
+            }
+            if (firstName.isEmpty()) {
+                firstName = e.text().trimmed();
+            }
         }
     }
+    if (mName.isEmpty()) {
+        // Just a fallback, because those are quite nice to have...
+        mName = firstName;
+    }
 
     // Validation
     if ((mNoUploadUrl.isValid()) && (mUploadUrl.isValid())) {
@@ -85,6 +107,12 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
         return false;
     }
 
+    if (mUploadUrl.isValid()) {
+        setWebsite(mUploadUrl);
+    } else {
+        setWebsite(mNoUploadUrl);
+    }
+
     mId = mDownloadUrls[QString()].url();
     if (mId.isEmpty()) {
         mId = mDownloadUrls[mDownloadUrls.begin().key()].url();
@@ -124,14 +152,18 @@ void StaticXmlProvider::loadEntries(const KNSCore::Provider::SearchRequest &requ
 
     if (request.filter == Installed) {
         qCDebug(KNEWSTUFFCORE) << "Installed entries: " << mId << installedEntries().size();
-        Q_EMIT loadingFinished(request, installedEntries());
+        if (request.page == 0) {
+            Q_EMIT loadingFinished(request, installedEntries());
+        } else {
+            Q_EMIT loadingFinished(request, EntryInternal::List());
+        }
         return;
     }
 
     QUrl url = downloadUrl(request.sortMode);
     if (!url.isEmpty()) {
         // TODO first get the entries, then filter with searchString, finally emit the finished signal...
-        // FIXME: don't creat an endless number of xmlloaders!
+        // FIXME: don't create an endless number of xmlloaders!
         XmlLoader *loader = new XmlLoader(this);
         connect(loader, &XmlLoader::signalLoaded, this, &StaticXmlProvider::slotFeedFileLoaded);
         connect(loader, &XmlLoader::signalFailed, this, &StaticXmlProvider::slotFeedFailed);
@@ -288,7 +320,7 @@ void StaticXmlProvider::loadPayloadLink(const KNSCore::EntryInternal &entry, int
 EntryInternal::List StaticXmlProvider::installedEntries() const
 {
     EntryInternal::List entries;
-    for (const EntryInternal &entry : qAsConst(mCachedEntries)) {
+    for (const EntryInternal &entry : std::as_const(mCachedEntries)) {
         if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
             entries.append(entry);
         }
@@ -297,3 +329,5 @@ EntryInternal::List StaticXmlProvider::installedEntries() const
 }
 
 }
+
+#include "moc_staticxmlprovider_p.cpp"
