@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "imagepreviewwidget_p.h"
@@ -22,17 +11,14 @@
 
 #include <qstandardpaths.h>
 
-#include <core/entryinternal_p.h>
+#include <core/entryinternal.h>
 
 using namespace KNS3;
 
-ImagePreviewWidget::ImagePreviewWidget(QWidget *parent) :
-    QWidget(parent)
+ImagePreviewWidget::ImagePreviewWidget(QWidget *parent)
+    : QWidget(parent)
 {
-    //installEventFilter(this);
-
-    QString framefile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/knewstuff/pics/thumb_frame.png"));
-    m_frameImage = QPixmap(framefile);
+    // installEventFilter(this);
 }
 
 void ImagePreviewWidget::setImage(const QImage &preview)
@@ -46,7 +32,7 @@ void ImagePreviewWidget::setImage(const QImage &preview)
 void ImagePreviewWidget::mousePressEvent(QMouseEvent *event)
 {
     QWidget::mousePressEvent(event);
-    emit clicked();
+    Q_EMIT clicked();
 }
 
 void ImagePreviewWidget::resizeEvent(QResizeEvent *event)
@@ -64,7 +50,7 @@ void ImagePreviewWidget::paintEvent(QPaintEvent * /*event*/)
 
     QPainter painter(this);
     int margin = painter.fontMetrics().height() / 2;
-    //painter.drawImage(contentsRect(), m_image);
+    // painter.drawImage(contentsRect(), m_image);
 
     int width = contentsRect().width();
     int height = contentsRect().height();
@@ -80,7 +66,6 @@ void ImagePreviewWidget::paintEvent(QPaintEvent * /*event*/)
     point.setY(contentsRect().top() + ((height - m_scaledImage.height()) / 2));
 
     QPoint framePoint(point.x() - 5, point.y() - 5);
-    painter.drawPixmap(framePoint, m_frameImage.scaled(m_scaledImage.width() + 10, m_scaledImage.height() + 10));
     painter.drawImage(point, m_scaledImage);
 }
 
@@ -93,3 +78,5 @@ QSize ImagePreviewWidget::sizeHint() const
     sh.scale(maximumSize(), Qt::KeepAspectRatio);
     return sh;
 }
+
+#include "moc_imagepreviewwidget_p.cpp"
